@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 """
 Script to build a Swift ring from a declarative YAML configuration. This has
@@ -33,8 +33,6 @@ hosts:
       - device: /dev/sdc
         weight: 100
 """
-
-from __future__ import print_function
 import subprocess
 import sys
 
@@ -122,7 +120,7 @@ def main():
     build_path = sys.argv[2]
     service_name = sys.argv[3]
     with open(config_path) as f:
-        config = yaml.safe_load(f)
+        config = yaml.load(f)
     build_rings(config, build_path, service_name)
 
 
